@@ -160,10 +160,12 @@ def process_request(request, cls, form_obj, form_name, obj_id, template):
 
         if form.is_valid():
             form.save()
-            success = True
+            res = True
+        else:
+            res['errors'] = form.errors
 
-            json = simplejson.dumps(res)
-            return HttpResponse(json, mimetype='application/json')
+        json = simplejson.dumps(res)
+        return HttpResponse(json, mimetype='application/json')
 
     data = {
         'form_name': form_name,
